package com.ruoyi.ems.service;

import java.util.List;

import com.ruoyi.ems.domain.ElecValencyStrategy;

/**
 * 电价策略Service接口
 * 
 * @author ruoyi
 * @date 2024-07-23
 */
public interface IElecValencyStrategyService
{
    /**
     * 查询电价策略
     * 
     * @param id 电价策略主键
     * @return 电价策略
     */
     ElecValencyStrategy selectStrategyById(Long id);

    /**
     * 查询电价策略列表
     * 
     * @param strategy 电价策略
     * @return 电价策略集合
     */
     List<ElecValencyStrategy> selectStrategyList(ElecValencyStrategy strategy);

    /**
     * 新增电价策略
     * 
     * @param elecValencyStrategy 电价策略
     * @return 结果
     */
     int insertStrategy(ElecValencyStrategy strategy);

    /**
     * 修改电价策略
     * 
     * @param strategy 电价策略
     * @return 结果
     */
     int updateStrategy(ElecValencyStrategy strategy);

    /**
     * 批量删除电价策略
     * 
     * @param ids 需要删除的电价策略主键集合
     * @return 结果
     */
     int deleteStrategyByIds(Long[] ids);

    /**
     * 删除电价策略信息
     * 
     * @param id 电价策略主键
     * @return 结果
     */
     int deleteStrategyById(Long id);
}
